Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1846)

Unified Diff: apps/app_shim/app_shim_host_manager_mac.mm

Issue 305973002: Rename IPC::ChannelFactory to ChannelHandleAcceptor. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « apps/app_shim/app_shim_host_manager_mac.h ('k') | apps/app_shim/test/app_shim_host_manager_test_api_mac.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: apps/app_shim/app_shim_host_manager_mac.mm
diff --git a/apps/app_shim/app_shim_host_manager_mac.mm b/apps/app_shim/app_shim_host_manager_mac.mm
index 769b1669bb02eb7ef7228fc928ef7192a1f3fabb..799d32d0e979a69cb1051555791ba8da515c42f6 100644
--- a/apps/app_shim/app_shim_host_manager_mac.mm
+++ b/apps/app_shim/app_shim_host_manager_mac.mm
@@ -64,7 +64,7 @@ void AppShimHostManager::Init() {
}
AppShimHostManager::~AppShimHostManager() {
- factory_.reset();
+ acceptor_.reset();
if (!did_init_)
return;
@@ -105,10 +105,10 @@ void AppShimHostManager::InitOnFileThread() {
return;
}
- // IPC::ChannelFactory creates the socket immediately.
+ // UnixDomainSocketAcceptor creates the socket immediately.
base::FilePath socket_path =
directory_in_tmp_.Append(app_mode::kAppShimSocketShortName);
- factory_.reset(new IPC::ChannelFactory(socket_path, this));
+ acceptor_.reset(new apps::UnixDomainSocketAcceptor(socket_path, this));
// Create a symlink to the socket in the user data dir. This lets the shim
// process started from Finder find the actual socket path by following the
@@ -125,7 +125,7 @@ void AppShimHostManager::InitOnFileThread() {
void AppShimHostManager::ListenOnIOThread() {
DCHECK(BrowserThread::CurrentlyOn(BrowserThread::IO));
- if (!factory_->Listen()) {
+ if (!acceptor_->Listen()) {
BrowserThread::PostTask(
BrowserThread::UI, FROM_HERE,
base::Bind(&AppShimHostManager::OnListenError, this));
@@ -142,7 +142,7 @@ void AppShimHostManager::OnClientConnected(
void AppShimHostManager::OnListenError() {
// TODO(tapted): Set a timeout and attempt to reconstruct the channel. Until
// cases where the error could occur are better known, just reset the factory
// to allow failure to be communicated via the test API.
- factory_.reset();
+ acceptor_.reset();
}
« no previous file with comments | « apps/app_shim/app_shim_host_manager_mac.h ('k') | apps/app_shim/test/app_shim_host_manager_test_api_mac.h » ('j') | no next file with comments »
@@ -142,7 +142,7 @@ void AppShimHostManager::OnClientConnected(
void AppShimHostManager::OnListenError() {
// TODO(tapted): Set a timeout and attempt to reconstruct the channel. Until
- // cases where the error could occur are better known, just reset the factory
+ // cases where the error could occur are better known, just reset the acceptor
// to allow failure to be communicated via the test API.

Powered by Google App Engine
This is Rietveld 408576698